@@ -147,6 +147,15 @@ def human_readable_size(size):
     else:
         return "%.2f TB" % (size / float(2**40))
 
+def build_carray(rootdir):
+    """ Used in ctable.__reduce__
+
+    Pickling functions can't be in pyx files.  Putting this tiny helper
+    function here instead.
+    """
+    from bcolz import carray
+    return carray(rootdir=rootdir)
+
 
 # Main part
 # =========
